append_factor_key: Create key to partition results by scenario

View source: R/append_factor_key.R

append_factor_keyR Documentation

Create key to partition results by scenario

Description

Create key to partition results by scenario

Usage

append_factor_key(scenario_res, partition_by)

Arguments

scenario_res

Data frame as returned by load_param_space()which is identical to a scenarios' parameter space as as read by calc_ed95_for_plots(). In addition to the columns in the parameter spaces, 5 columns are appended with the ed95 statistic obtained for each set parameter set:

  • $ed95_spec_nltt

  • $ed95_endemic_nltt

  • $ed95_nonendemic_nltt

  • $ed95_num_spec

  • $ed95_num_col

partition_by

String with the feature by which the results should be grouped for plotting. Options are:

  • "hyperparameters"

  • "gradient"

  • "sample_parameters"

  • "land_bridge_multiplier"

Value

A data frame with a parameter space and corresponding ed95 results returned by calc_ed95_for_plots(). In addition, a column $key is appended at the right hand side with the factors by which the data should be grouped for plotting.

Author(s)

Pedro Santos Neves


Neves-P/DAISIErobustness documentation built on May 22, 2024, 4:26 p.m.