View source: R/calc_error_metrics.R
| calc_error_metrics | R Documentation |
Calculates metrics between error and baseline error distributions
calc_error_metrics(
spec_nltt_error,
num_spec_error,
num_col_error,
endemic_nltt_error,
nonendemic_nltt_error,
spec_baseline_nltt_error,
num_spec_baseline_error,
num_col_baseline_error,
endemic_baseline_nltt_error,
nonendemic_baseline_nltt_error
)
spec_nltt_error |
Numeric vector with the nltt error from the novel simulation and the oceanic DAISIE simulation. |
num_spec_error |
Numeric vector with the difference in the number of species at the end of the simulation between the novel simulation and the oceanic DAISIE simulation. |
num_col_error |
Numeric vector with the difference in the number of colonists at the end of the simulation between the novel simulation and the oceanic DAISIE simulation. |
endemic_nltt_error |
Numeric vector with the nltt error of the endemic species from the novel simulation and the oceanic DAISIE simulation. |
nonendemic_nltt_error |
Numeric vector with the nltt error of the non-endemic species from the novel simulation and the oceanic DAISIE simulation. |
spec_baseline_nltt_error |
Numeric vector with the baseline nltt error between oceanic DAISIE simulations. |
num_spec_baseline_error |
Numeric vector with the difference in the number of species at the end of the simulation between the oceanic DAISIE simulations. |
num_col_baseline_error |
Numeric vector with the difference in the number of colonists at the end of the simulation between the oceanic DAISIE simulations. |
endemic_baseline_nltt_error |
Numeric vector with the nltt error of the endemic species from the oceanic DAISIE simulations. |
nonendemic_baseline_nltt_error |
Numeric vector with the nltt error of the non-endemic species from the oceanic DAISIE simulations. |
a list of numerics
Joshua W. Lambert, Pedro Santos Neves, Shu Xie
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.