create_output_file_name: Generated name for saving output of 'run_robustness()'

View source: R/input-output.R

create_output_file_nameR Documentation

Generated name for saving output of run_robustness()

Description

Generated name for saving output of run_robustness()

Usage

create_output_file_name(param_space_name, param_set)

Arguments

param_space_name

A string with the parameter space to run. See is_param_space_name() for options.

param_set

A numeric with the line corresponding to parameter set to run, as found in the file named in param_space.

Value

Character with name indicating the name of the parameter space, the numeric id of the param_set and whether the run passed constraints.

Author(s)

Joshua W. Lambert, Pedro Santos Neves, Shu Xie

See Also

Other I/O: check_create_folders(), save_output()

Examples

testit::assert(
  DAISIErobustness:::create_output_file_name(
    param_space_name = "oceanic_ontogeny_cs",
    param_set = 1
  ) == "oceanic_ontogeny_cs_param_set_1.rds"
)

Neves-P/DAISIErobustness documentation built on May 22, 2024, 4:26 p.m.