default_params_doc: Default parameter documentation

View source: R/default_params_doc.R

default_params_docR Documentation

Default parameter documentation

Description

Default parameter documentation

Usage

default_params_doc(
  param_space_name,
  param_set,
  replicates,
  save_output,
  output,
  param_space,
  sim_pars,
  sim,
  novel_sim,
  ml,
  ml_res_initpars_1,
  ml_res_initpars_2,
  ml_constraints,
  initial_parameters,
  sim_1,
  sim_2,
  spec_error,
  endemic_error,
  nonendemic_error,
  spec_baseline_error,
  endemic_baseline_error,
  nonendemic_baseline_error,
  distance_method,
  spec_nltt_error,
  num_spec_error,
  num_col_error,
  endemic_nltt_error,
  nonendemic_nltt_error,
  spec_baseline_nltt_error,
  num_spec_baseline_error,
  num_col_baseline_error,
  endemic_baseline_nltt_error,
  nonendemic_baseline_nltt_error,
  folder_path,
  param_set_range,
  test,
  log_file_path,
  logs_folder_path,
  runtime_params,
  ed95_param_sets,
  param_space_data_frame,
  log_lines,
  partition_by,
  scenario_res
)

Arguments

param_space_name

A string with the parameter space to run. See is_param_space_name() for options.

param_set

A numeric with the line corresponding to parameter set to run, as found in the file named in param_space.

replicates

A numeric for the number of replicates for the simulations

save_output

A boolean to determine whether to save or return output.

output

List. Contains all the pipeline output that was able to run up to a given point. Will be saved into .rds file by save_output() if the run_robustness() argument save_output is TRUE.

param_space

A data frame of the parameter space.

sim_pars

A list of simulation parameters.

sim

A list of simulation output from DAISIE_sim_cr(), DAISIE_sim_time_dep(), DAISIE_sim_cr_shift(), DAISIE_sim_trait_dep() or other input simulation in the DAISIE sim format.

novel_sim

A list of simulation output in the DAISIE simulation format for which the robustness against standard oceanic DAISIE is to be determined. Can be generated from a preset of models available in run_novel_sim(), or loaded from a file, if in the correct format.

ml

Output from DAISIE_ML().

ml_res_initpars_1

Numeric data frame. Results from MLE run of geodynamics with the first set of initial parameters.

ml_res_initpars_2

Numeric data frame. Results from MLE run of geodynamics with the second set of initial parameters.

ml_constraints

Boolean. TRUE if MLE constraints pass, FALSE otherwise.

initial_parameters

A numeric vector of length 5 with the initial parameters for the MLE routine. The same as initparsopt from DAISIE_ML().

sim_1

A list of simulation output from DAISIE_sim_cr(), DAISIE_sim_time_dep(), DAISIE_sim_cr_shift(), or DAISIE_sim_trait_dep().

sim_2

A list of simulation output from DAISIE_sim_cr(), DAISIE_sim_time_dep() or DAISIE_sim_cr_shift(), or DAISIE_sim_trait_dep().

spec_error

A list with three elements each with a numeric vector.

endemic_error

A list with one element with a numeric vector.

nonendemic_error

A list with one element with a numeric vector.

spec_baseline_error

A list with three elements each with a numeric vector.

endemic_baseline_error

A list with one element with a numeric vector.

nonendemic_baseline_error

A list with one element with a numeric vector.

distance_method

From the nLTT package. How the difference between the two nLTTs is summed:

  • "abs": the absolute distance between the two nLTTs is summed

  • "squ": the squared distance between the two nLTTs is summed

spec_nltt_error

Numeric vector with the nltt error from the novel simulation and the oceanic DAISIE simulation.

num_spec_error

Numeric vector with the difference in the number of species at the end of the simulation between the novel simulation and the oceanic DAISIE simulation.

num_col_error

Numeric vector with the difference in the number of colonists at the end of the simulation between the novel simulation and the oceanic DAISIE simulation.

endemic_nltt_error

Numeric vector with the nltt error of the endemic species from the novel simulation and the oceanic DAISIE simulation.

nonendemic_nltt_error

Numeric vector with the nltt error of the non-endemic species from the novel simulation and the oceanic DAISIE simulation.

spec_baseline_nltt_error

Numeric vector with the baseline nltt error between oceanic DAISIE simulations.

num_spec_baseline_error

Numeric vector with the difference in the number of species at the end of the simulation between the oceanic DAISIE simulations.

num_col_baseline_error

Numeric vector with the difference in the number of colonists at the end of the simulation between the oceanic DAISIE simulations.

endemic_baseline_nltt_error

Numeric vector with the nltt error of the endemic species from the oceanic DAISIE simulations.

nonendemic_baseline_nltt_error

Numeric vector with the nltt error of the non-endemic species from the oceanic DAISIE simulations.

folder_path

A file path (use file.path() for formatting convenience) where all the parameter sets results of a given parameter space are stored in .rds format.

param_set_range

Defaults to NULL, which computes the ED95 statistic for all parameter sets in the file of the parameter space located in folder_path. Otherwise, a numeric vector of length 2, where the first element must be lower than the second. This specifies the range of parameter sets to load compute ED95 for, i.e c(1, 20) will attempt to compute and load parameter sets 1 to 20. If there are gaps in this range, the function works regardless, and will return ED95 for the parameter set results within the 1 to 20 range.

test

A boolean, defaults to 'FALSE'. Set to 'TRUE' for testing purposes, to fix the seed.

log_file_path

A string with the path for a standard Peregrine HPCC log file.

logs_folder_path

A string with the path for a directory containing the Peregrine HPCC log files.

runtime_params

A data frame with runtime of each parameter set in each parameter space as returned by get_runtime_params().

ed95_param_sets

A data frame with all ED95 statistics of each parameter set in each parameter space as returned by calc_ed95_param_set().

param_space_data_frame

A data frame with ED95 statistics all parameter spaces, together with associated runtime. Used for plotting correlation between runtime and ED95. Obtained by running calc_ed95_param_set().

log_lines

Character vector containing the contents of the log files as read by read_log_file().

partition_by

String with the feature by which the results should be grouped for plotting. Options are:

  • "hyperparameters"

  • "gradient"

  • "sample_parameters"

  • "land_bridge_multiplier"

scenario_res

Data frame as returned by load_param_space()which is identical to a scenarios' parameter space as as read by calc_ed95_for_plots(). In addition to the columns in the parameter spaces, 5 columns are appended with the ed95 statistic obtained for each set parameter set:

  • $ed95_spec_nltt

  • $ed95_endemic_nltt

  • $ed95_nonendemic_nltt

  • $ed95_num_spec

  • $ed95_num_col

Value

Nothing

Author(s)

Joshua W. Lambert, Pedro Santos Neves, Shu Xie


Neves-P/DAISIErobustness documentation built on May 22, 2024, 4:26 p.m.