View source: R/get_runtime_params.R
| get_runtime_params | R Documentation |
Make runtime data frame
get_runtime_params(logs_folder_path)
logs_folder_path |
A string with the path for a directory containing the Peregrine HPCC log files. |
A data frame with three columns:
param_space_nameAtomic character vector with parameter space name.
param_setAtomic numeric vector with parameter space number.
runtimeAtomic numeric vector with Peregrine job run time in seconds.
statuscharacter with job status upon conclusion.
log_nameCharacter vector with name of corresponding log file to facilitate debugging.
Pedro Santos Neves
## Not run:
runtimes_data_frame <- get_runtime_params("logs/")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.