load_param_space: Loads the parameter space into the environment for...

View source: R/load_param_space.R

load_param_spaceR Documentation

Loads the parameter space into the environment for simulations

Description

Loads the parameter space into the environment for simulations

Usage

load_param_space(param_space_name)

Arguments

param_space_name

A string with the parameter space to run. See is_param_space_name() for options.

Value

Data frame with the parameter space.

Author(s)

Joshua W. Lambert, Pedro Santos Neves, Shu Xie


Neves-P/DAISIErobustness documentation built on May 22, 2024, 4:26 p.m.