View source: R/read_log_file.R
| read_log_file | R Documentation |
Simply sanitizes the input path and reads log files into a character vector.
read_log_file(log_file_path)
log_file_path |
A string with the path for a standard Peregrine HPCC log file. |
Character vector with the contents of the log file as returned by
readLines().
Pedro Santos Neves
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.