save_output: Save 'run_robustness()' output

View source: R/input-output.R

save_outputR Documentation

Save run_robustness() output

Description

Save run_robustness() output

Usage

save_output(output, param_space_name, param_set)

Arguments

output

List. Contains all the pipeline output that was able to run up to a given point. Will be saved into .rds file by save_output() if the run_robustness() argument save_output is TRUE.

param_space_name

A string with the parameter space to run. See is_param_space_name() for options.

param_set

A numeric with the line corresponding to parameter set to run, as found in the file named in param_space.

Details

Files are saved to a subdirectory named after param_space_name within the current directory. The /results/ directory and subfolders are created if they don't exist. The status of saving is printed as a message if successful, a warning if unsuccessful.

Value

.rds file named by create_output_file_name() in default location. See details for more information on filesystem. This

Author(s)

Joshua W. Lambert, Pedro Santos Neves, Shu Xie

See Also

Other I/O: check_create_folders(), create_output_file_name()


Neves-P/DAISIErobustness documentation built on May 22, 2024, 4:26 p.m.