View source: R/append_factor_key.R
| append_factor_key | R Documentation |
Create key to partition results by scenario
append_factor_key(scenario_res, partition_by)
scenario_res |
Data frame as returned by
|
partition_by |
String with the feature by which the results should be grouped for plotting. Options are:
|
A data frame with a parameter space and corresponding ed95 results
returned by calc_ed95_for_plots(). In addition, a column
$key is appended at the right hand side with the factors by which
the data should be grouped for plotting.
Pedro Santos Neves
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.