| create_output_file_name | R Documentation |
run_robustness()Generated name for saving output of run_robustness()
create_output_file_name(param_space_name, param_set)
param_space_name |
A string with the parameter space to run. See
|
param_set |
A numeric with the line corresponding to parameter set to
run, as found in the file named in |
Character with name indicating the name of the parameter space, the numeric id of the param_set and whether the run passed constraints.
Joshua W. Lambert, Pedro Santos Neves, Shu Xie
Other I/O:
check_create_folders(),
save_output()
testit::assert(
DAISIErobustness:::create_output_file_name(
param_space_name = "oceanic_ontogeny_cs",
param_set = 1
) == "oceanic_ontogeny_cs_param_set_1.rds"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.