View source: R/default_params_doc.R
| default_params_doc | R Documentation |
Default parameter documentation
default_params_doc(
param_space_name,
param_set,
replicates,
save_output,
output,
param_space,
sim_pars,
sim,
novel_sim,
ml,
ml_res_initpars_1,
ml_res_initpars_2,
ml_constraints,
initial_parameters,
sim_1,
sim_2,
spec_error,
endemic_error,
nonendemic_error,
spec_baseline_error,
endemic_baseline_error,
nonendemic_baseline_error,
distance_method,
spec_nltt_error,
num_spec_error,
num_col_error,
endemic_nltt_error,
nonendemic_nltt_error,
spec_baseline_nltt_error,
num_spec_baseline_error,
num_col_baseline_error,
endemic_baseline_nltt_error,
nonendemic_baseline_nltt_error,
folder_path,
param_set_range,
test,
log_file_path,
logs_folder_path,
runtime_params,
ed95_param_sets,
param_space_data_frame,
log_lines,
partition_by,
scenario_res
)
param_space_name |
A string with the parameter space to run. See
|
param_set |
A numeric with the line corresponding to parameter set to
run, as found in the file named in |
replicates |
A numeric for the number of replicates for the simulations |
save_output |
A boolean to determine whether to save or return output. |
output |
List. Contains all the pipeline output that was able to
run up to a given point. Will be saved into .rds file by
|
param_space |
A data frame of the parameter space. |
sim_pars |
A list of simulation parameters. |
sim |
A list of simulation output from
|
novel_sim |
A list of simulation output in the DAISIE simulation format
for which the robustness against standard oceanic DAISIE is to be
determined.
Can be generated from a preset of models available in
|
ml |
Output from |
ml_res_initpars_1 |
Numeric data frame. Results from MLE run of geodynamics with the first set of initial parameters. |
ml_res_initpars_2 |
Numeric data frame. Results from MLE run of geodynamics with the second set of initial parameters. |
ml_constraints |
Boolean. |
initial_parameters |
A numeric vector of length 5 with the initial
parameters for the MLE routine. The same as |
sim_1 |
A list of simulation output from
|
sim_2 |
A list of simulation output from
|
spec_error |
A list with three elements each with a numeric vector. |
endemic_error |
A list with one element with a numeric vector. |
nonendemic_error |
A list with one element with a numeric vector. |
spec_baseline_error |
A list with three elements each with a numeric vector. |
endemic_baseline_error |
A list with one element with a numeric vector. |
nonendemic_baseline_error |
A list with one element with a numeric vector. |
distance_method |
From the nLTT package. How the difference between the two nLTTs is summed:
|
spec_nltt_error |
Numeric vector with the nltt error from the novel simulation and the oceanic DAISIE simulation. |
num_spec_error |
Numeric vector with the difference in the number of species at the end of the simulation between the novel simulation and the oceanic DAISIE simulation. |
num_col_error |
Numeric vector with the difference in the number of colonists at the end of the simulation between the novel simulation and the oceanic DAISIE simulation. |
endemic_nltt_error |
Numeric vector with the nltt error of the endemic species from the novel simulation and the oceanic DAISIE simulation. |
nonendemic_nltt_error |
Numeric vector with the nltt error of the non-endemic species from the novel simulation and the oceanic DAISIE simulation. |
spec_baseline_nltt_error |
Numeric vector with the baseline nltt error between oceanic DAISIE simulations. |
num_spec_baseline_error |
Numeric vector with the difference in the number of species at the end of the simulation between the oceanic DAISIE simulations. |
num_col_baseline_error |
Numeric vector with the difference in the number of colonists at the end of the simulation between the oceanic DAISIE simulations. |
endemic_baseline_nltt_error |
Numeric vector with the nltt error of the endemic species from the oceanic DAISIE simulations. |
nonendemic_baseline_nltt_error |
Numeric vector with the nltt error of the non-endemic species from the oceanic DAISIE simulations. |
folder_path |
A file path (use |
param_set_range |
Defaults to |
test |
A boolean, defaults to 'FALSE'. Set to 'TRUE' for testing purposes, to fix the seed. |
log_file_path |
A string with the path for a standard Peregrine HPCC log file. |
logs_folder_path |
A string with the path for a directory containing the Peregrine HPCC log files. |
runtime_params |
A data frame with runtime of each parameter set in each
parameter space as returned by |
ed95_param_sets |
A data frame with all ED95 statistics of each
parameter set in each parameter space as returned by
|
param_space_data_frame |
A data frame with ED95 statistics all
parameter spaces, together with associated runtime. Used for plotting
correlation between runtime and ED95. Obtained by running
|
log_lines |
Character vector containing the contents of the log files
as read by |
partition_by |
String with the feature by which the results should be grouped for plotting. Options are:
|
scenario_res |
Data frame as returned by
|
Nothing
Joshua W. Lambert, Pedro Santos Neves, Shu Xie
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.