| save_output | R Documentation |
run_robustness() outputSave run_robustness() output
save_output(output, param_space_name, param_set)
output |
List. Contains all the pipeline output that was able to
run up to a given point. Will be saved into .rds file by
|
param_space_name |
A string with the parameter space to run. See
|
param_set |
A numeric with the line corresponding to parameter set to
run, as found in the file named in |
Files are saved to a subdirectory named after
param_space_name within the current directory. The /results/
directory and subfolders are created if they don't exist. The status of
saving is printed as a message if successful, a warning if unsuccessful.
.rds file named by create_output_file_name() in
default location. See details for more information on filesystem. This
Joshua W. Lambert, Pedro Santos Neves, Shu Xie
Other I/O:
check_create_folders(),
create_output_file_name()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.